@@ -25,7 +25,7 @@ from pytensor.tensor.basic import (
     cast,
     concatenate,
     extract_constant,
-    get_scalar_constant_value,
+    get_underlying_scalar_constant_value,
     switch,
 )
 from pytensor.tensor.elemwise import Elemwise
@@ -479,6 +479,7 @@ def local_subtensor_merge(fgraph, node):
     expresses all slices in a canonical form, and then merges them together.
 
     """
+    from pytensor.scan.op import Scan
 
     if isinstance(node.op, Subtensor):
         u = node.inputs[0]
@@ -489,6 +490,16 @@ def local_subtensor_merge(fgraph, node):
             # slices of the first applied subtensor
             slices1 = get_idx_list(u.owner.inputs, u.owner.op.idx_list)
             slices2 = get_idx_list(node.inputs, node.op.idx_list)
+
+            # Don't try to do the optimization on do-while scan outputs,
+            # as it will create a dependency on the shape of the outputs
+            if (
+                x.owner is not None
+                and isinstance(x.owner.op, Scan)
+                and x.owner.op.info.as_while
+            ):
+                return None
+
             # Get the shapes of the vectors !
             try:
                 # try not to introduce new shape into the graph
@@ -745,7 +756,9 @@ def local_subtensor_make_vector(fgraph, node):
     elif isinstance(idx, Variable):
         if idx.ndim == 0:
             try:
-                v = get_scalar_constant_value(idx, only_process_constants=True)
+                v = get_underlying_scalar_constant_value(
+                    idx, only_process_constants=True
+                )
                 try:
                     ret = [x.owner.inputs[v]]
                 except IndexError:
@@ -797,7 +810,7 @@ def local_useless_inc_subtensor(fgraph, node):
         # This is an increment operation, so the array being incremented must
         # consist of all zeros in order for the entire operation to be useless
         try:
-            c = get_scalar_constant_value(x)
+            c = get_underlying_scalar_constant_value(x)
             if c != 0:
                 return
         except NotScalarConstantError:
@@ -916,7 +929,7 @@ def local_useless_subtensor(fgraph, node):
         if isinstance(idx.stop, (int, np.integer)):
             length_pos_data = sys.maxsize
             try:
-                length_pos_data = get_scalar_constant_value(
+                length_pos_data = get_underlying_scalar_constant_value(
                     length_pos, only_process_constants=True
                 )
             except NotScalarConstantError:
@@ -981,7 +994,7 @@ def local_useless_AdvancedSubtensor1(fgraph, node):
 
     # get length of the indexed tensor along the first axis
     try:
-        length = get_scalar_constant_value(
+        length = get_underlying_scalar_constant_value(
             shape_of[node.inputs[0]][0], only_process_constants=True
         )
     except NotScalarConstantError:
@@ -1318,7 +1331,7 @@ def local_incsubtensor_of_zeros(fgraph, node):
         try:
             # Don't use only_process_constants=True. We need to
             # investigate Alloc of 0s but with non constant shape.
-            if get_scalar_constant_value(y, elemwise=False) == 0:
+            if get_underlying_scalar_constant_value(y, elemwise=False) == 0:
                 # No need to copy over the stacktrace,
                 # because x should already have a stacktrace
                 return [x]
@@ -1364,12 +1377,12 @@ def local_setsubtensor_of_constants(fgraph, node):
         # Don't use only_process_constants=True. We need to
         # investigate Alloc of 0s but with non constant shape.
         try:
-            replace_x = get_scalar_constant_value(x, elemwise=False)
+            replace_x = get_underlying_scalar_constant_value(x, elemwise=False)
         except NotScalarConstantError:
             return
 
         try:
-            replace_y = get_scalar_constant_value(y, elemwise=False)
+            replace_y = get_underlying_scalar_constant_value(y, elemwise=False)
         except NotScalarConstantError:
             return
 
@@ -1657,7 +1670,7 @@ def local_join_subtensors(fgraph, node):
     axis, tensors = node.inputs[0], node.inputs[1:]
 
     try:
-        axis = get_scalar_constant_value(axis)
+        axis = get_underlying_scalar_constant_value(axis)
     except NotScalarConstantError:
         return
 
@@ -1718,7 +1731,12 @@ def local_join_subtensors(fgraph, node):
             if step is None:
                 continue
             try:
-                if get_scalar_constant_value(step, only_process_constants=True) != 1:
+                if (
+                    get_underlying_scalar_constant_value(
+                        step, only_process_constants=True
+                    )
+                    != 1
+                ):
                     return None
             except NotScalarConstantError:
                 return None
